(define-module (glicid packages linux)
  #:use-module (guix packages)
  #:use-module (guix download)
  #:use-module (guix git-download)
  #:use-module ((guix licenses) #:prefix license:)
  #:use-module (guix build-system gnu)
  #:use-module (guix build-system go)
  #:use-module (gnu packages backup)
  #:use-module (gnu packages compression)
  #:use-module (gnu packages cryptsetup)
  #:use-module (gnu packages golang)
  #:use-module ((gnu packages linux) #:prefix gnu:)
  #:use-module (gnu packages linux) ;; yes : redundant FIXIT
  #:use-module (gnu system uuid)
  #:use-module (gnu packages pkg-config)
  #:use-module (gnu packages autotools)
  #:use-module (gnu packages python)
  #:use-module (gnu packages tls)
;  #:use-module (glicid packages golang)
  #:use-module (glicid utils)
)

(define-public rdma-core-upstream-37.1
  (package
    (inherit gnu:rdma-core)
    (name (string-append (package-name gnu:rdma-core) "-upstream" ))
    (version "37.1")
    (source
      (origin
        (method url-fetch)
        (uri (string-append "https://github.com/linux-rdma/rdma-core/releases/download/v" version "/rdma-core-" version ".tar.gz"))
        (sha256 (base32 "1hjwagf5x48vgshy5s01qjlzjr8kmxpflfcvh8pgj3zbj82zzxiz"))
      )
    )
  )
)

(define-public rdma-core-upstream-38.0
  (package
    (inherit gnu:rdma-core)
    (name (string-append (package-name gnu:rdma-core) "-upstream" ))
    (version "38.0")
    (source
      (origin
        (method url-fetch)
        (uri (string-append "https://github.com/linux-rdma/rdma-core/releases/download/v" version "/rdma-core-" version ".tar.gz"))
        (sha256 (base32 "043vybwx9kz4mbbmnj0jzkzsw02vzhkkjc5j3yjdiiqkmsgwr3cs"))
      )
    )
  )
)

(define-public rdma-core-upstream-39.0
  (package
    (inherit gnu:rdma-core)
    (name (string-append (package-name gnu:rdma-core) "-upstream" ))
    (version "39.0")
    (source
      (origin
        (method url-fetch)
        (uri (string-append "https://github.com/linux-rdma/rdma-core/releases/download/v" version "/rdma-core-" version ".tar.gz"))
        (sha256 (base32 "0y13px3qgyh3szywjhikw183y54iym9sa60aw0sf51p3kzgg1spn"))
      )
    )   
  )
)

(define local-rdma-core rdma-core-upstream-39.0)

(define-public rdma-core-latest (latest-version local-rdma-core gnu:rdma-core))

(define-public libfabric-upstream-1.13.1
  (package
    (inherit gnu:libfabric)
    (version "1.13.1")
    (name (string-append (package-name gnu:libfabric) "-upstream" ))
    (source
      (origin
        (method url-fetch)
        (uri (string-append "https://github.com/ofiwg/libfabric/releases/download/v" version "/libfabric-" version ".tar.bz2"))
        (sha256 (base32 "03nkhqjjyw3hwhxrn7rg30qc1gzc1r7p7lymyz5s96m3qhwfsvlf"))
      )
    )
  )
)

(define-public libfabric-upstream-1.14.0
  (package
    (inherit gnu:libfabric)
    (version "1.14.0")
    (name (string-append (package-name gnu:libfabric) "-upstream" ))
    (source
      (origin
        (method url-fetch)
        (uri (string-append "https://github.com/ofiwg/libfabric/releases/download/v" version "/libfabric-" version ".tar.bz2"))
        (sha256 (base32 "16klkzkg04wb699mqpi8mn2r8sqzj35zalynbdazyg4ghj4169pw"))
      )
    )
  )
)

(define-public libfabric-opx-beta-upstream-1.14.0-c

(let ((commit "e127cd074bbfd8c50b9f3cfb5b8e24162f8076a4"))
  (package
    (inherit gnu:libfabric)
    (version "1.14.0c")
    (name (string-append (package-name gnu:libfabric) "-opx-beta-upstream" ))

    (source
      (origin

       (method git-fetch)
        (uri (git-reference
          (url "https://github.com/ofiwg/libfabric.git")
            (commit commit)
         ))
        (file-name (git-file-name name version))
        (sha256 (base32 "0fh665l2xcl59zhbn63y5bm8v9s652gk5s8r094qb4if0bp3in04"))

      )
    )
     (inputs `(
      ("autoconf", autoconf)
      ("automake", automake)
      ("libtool", libtool)
      ("libuuid" , util-linux "lib")
      ("numactl" , gnu:numactl)
      ("psm2" , gnu:psm2)
      ,@(package-inputs gnu:libfabric)))
  
  )
 )   
)


(define-public libfabric-opx-beta-upstream-1.14.0-d

(let ((commit "e127cd074bbfd8c50b9f3cfb5b8e24162f8076a4"))
  (package
    (inherit gnu:libfabric)
    (version "1.14.0d")
    (name (string-append (package-name gnu:libfabric) "-opx-beta-upstream" ))

    (source
      (origin

       (method git-fetch)
        (uri (git-reference
          (url "https://github.com/ofiwg/libfabric.git")
            (commit commit)
         ))
        (file-name (git-file-name name version))
        (sha256 (base32 "0fh665l2xcl59zhbn63y5bm8v9s652gk5s8r094qb4if0bp3in04"))

      )
    )
     (inputs `(
      ("autoconf", autoconf)
      ("automake", automake)
      ("libtool", libtool)
   ;   ("libuuid" , util-linux "lib") ; intended : no psm3
      ("numactl" , gnu:numactl)
   ;   ("psm2" , gnu:psm2) ; intended : no psm2
      ,@(package-inputs gnu:libfabric)))

  )
 )   
)



;(define local-libfabric libfabric-opx-beta-upstream-1.14.0-c)
(define local-libfabric libfabric-opx-beta-upstream-1.14.0-d)

(define-public libfabric-latest (latest-version local-libfabric gnu:libfabric))

(define-public apptainer-singularity-3.8.5
  (package
    (name "singularity")
    (version "3.8.5")
    (source
      (origin
        (method url-fetch)
        (uri (string-append "https://github.com/apptainer/singularity/releases/download/v" version "/singularity-" version ".tar.gz"))
        (sha256 (base32 "1r1w2n1ndj5psvpm87ij6gwr0hwrbsn6gllv4q44spbvq2spizvz"))
      )
    )
    (home-page "https://apptainer.org/")
    (synopsis "THE CONTAINER SYSTEM FOR SECURE HIGH PERFORMANCE COMPUTING")
    (description "Apptainer/Singularity is the most widely used container system for HPC.
                  It is designed to execute applications at bare-metal performance while
                  being secure, portable, and 100% reproducible. Apptainer is an 
                  open-source project with a friendly community of developers and users.
                  The user base continues to expand, with Apptainer/Singularity now used
                  across industry and academia in many areas of work."
    )
    (license license:bsd-3)
    (build-system gnu-build-system)
    (inputs `(
      ("libarchive", libarchive)
      ("python", python-wrapper)
      ("zlib", zlib)
      ("squashfs-tools", squashfs-tools)
      ("openssl", openssl)
      ("libseccomp", gnu:libseccomp)
      ("cryptsetup", cryptsetup)
      ("go", go-1.17)
      ("pkg-config", pkg-config)
;      ("go-github-com-AdamKorcz-go-fuzz-headers", go-github-com-AdamKorcz-go-fuzz-headers)
;      ("go-github-com-Netflix-go-expect", go-github-com-Netflix-go-expect)
;      ("go-github-com-adigunhammedolalekan-registry-auth", go-github-com-adigunhammedolalekan-registry-auth)
;      ("go-github-com-alexflint-go-filemutex", go-github-com-alexflint-go-filemutex)
;      ("go-github-com-apex-log", go-github-com-apex-log)
;      ("go-github-com-blang-semver-v4", go-github-com-blang-semver-v4)
;      ("go-github-com-buger-jsonparser", go-github-com-buger-jsonparser)
;      ("go-github-com-bugsnag-bugsnag-go", go-github-com-bugsnag-bugsnag-go)
;      ("go-github-com-bugsnag-panicwrap", go-github-com-bugsnag-panicwrap)
;      ("go-github-com-containerd-cgroups", go-github-com-containerd-cgroups)
;      ("go-github-com-containerd-containerd", go-github-com-containerd-containerd)
;      ("go-github-com-containernetworking-cni", go-github-com-containernetworking-cni)
;      ("go-github-com-containernetworking-plugins", go-github-com-containernetworking-plugins)
;      ("go-github-com-containers-image-v5", go-github-com-containers-image-v5)
;      ("go-github-com-cyphar-filepath-securejoin", go-github-com-cyphar-filepath-securejoin)
;      ("go-github-com-fatih-color", go-github-com-fatih-color)
;      ("go-github-com-go-log-log", go-github-com-go-log-log)
;      ("go-github-com-godbus-dbus", go-github-com-godbus-dbus)
;      ("go-github-com-google-uuid", go-github-com-google-uuid)
;      ("go-github-com-gorilla-websocket", go-github-com-gorilla-websocket)
;      ("go-github-com-hpcng-sif", go-github-com-hpcng-sif)
;      ("go-github-com-kardianos-osext", go-github-com-kardianos-osext)
;      ("go-github-com-kr-pty", go-github-com-kr-pty)
;      ("go-github-com-opencontainers-go-digest", go-github-com-opencontainers-go-digest)
;      ("go-github-com-opencontainers-image-spec", go-github-com-opencontainers-image-spec)
;      ("go-github-com-opencontainers-runtime-spec", go-github-com-opencontainers-runtime-spec)
;      ("go-github-com-opencontainers-runtime-tools", go-github-com-opencontainers-runtime-tools)
;      ("go-github-com-opencontainers-selinux", go-github-com-opencontainers-selinux)
;      ("go-github-com-opencontainers-umoci", go-github-com-opencontainers-umoci)
;      ("go-github-com-pelletier-go-toml", go-github-com-pelletier-go-toml)
;      ("go-github-com-pkg-errors", go-github-com-pkg-errors)
;      ("go-github-com-russross-blackfriday-v2", go-github-com-russross-blackfriday-v2)
;      ("go-github-com-satori-go-uuid", go-github-com-satori-go-uuid)
;      ("go-github-com-seccomp-containers-golang", go-github-com-seccomp-containers-golang)
;      ("go-github-com-seccomp-libseccomp-golang", go-github-com-seccomp-libseccomp-golang)
;      ("go-github-com-spf13-cobra", go-github-com-spf13-cobra)
;      ("go-github-com-spf13-pflag", go-github-com-spf13-pflag)
;      ("go-github-com-sylabs-json-resp", go-github-com-sylabs-json-resp)
;      ("go-github-com-sylabs-scs-build-client", go-github-com-sylabs-scs-build-client)
;      ("go-github-com-sylabs-scs-key-client", go-github-com-sylabs-scs-key-client)
;      ("go-github-com-sylabs-scs-library-client", go-github-com-sylabs-scs-library-client)
;      ("go-github-com-urfave-cli", go-github-com-urfave-cli)
;      ("go-github-com-vbauerster-mpb-v4", go-github-com-vbauerster-mpb-v4)
;      ("go-github-com-vbauerster-mpb-v6", go-github-com-vbauerster-mpb-v6)
;      ("go-github-com-xeipuuv-gojsonpointer", go-github-com-xeipuuv-gojsonpointer)
;      ("go-github-com-yvasiyarov-go-metrics", go-github-com-yvasiyarov-go-metrics)
;      ("go-github-com-yvasiyarov-gorelic", go-github-com-yvasiyarov-gorelic)
;      ("go-github-com-yvasiyarov-newrelic_platform_go", go-github-com-yvasiyarov-newrelic_platform_go)
;      ("go-golang-org-x-crypto", go-golang-org-x-crypto)
;      ("go-golang-org-x-sys", go-golang-org-x-sys)
    ))
    (arguments
      `(#:phases
        (modify-phases %standard-phases
          (replace 'configure
            (lambda* (#:key inputs native-inputs propagated-inputs configure-flags #:allow-other-keys)
              (begin
                (invoke "./mconfig" "--localstatedir=/var")
              )
            )
          )
        )
      )
    )
  )
)


